<?php

function squirrelmail_plugin_init_change_passwd() 
{

   global $squirrelmail_plugin_hooks;

   $squirrelmail_plugin_hooks['optpage_register_block']['change_passwd'] = 'change_passwd_plugin_optpage_register_block';

}



function change_passwd_plugin_optpage_register_block() 
{

   if (defined('SM_PATH'))
      include_once(SM_PATH . 'plugins/change_passwd/functions.php');
   else
      include_once('../plugins/change_passwd/functions.php');

   change_passwd_plugin_optpage_register_block_do();

}


function change_passwd_version() 
{
   return '3.1';
}

?>
